/*******************************************************************************
	Estimate rural, urban, and total poverty rates by region

	/* Part 1: Aggregate total poverty rates across regions */
	/* Part 2: Aggregate rural / urban poverty rates across regions */
	/* Part 3: Combine data */ 
	
	Written by: Samuel Kofi Tetteh Baah (stettehbaah@worldbank.org)
	Last date modified: 10 August 2024     
*******************************************************************************/

// Load global distribution
use "$ch1_data_raw/other/global_profile_lineup_2022_country_level.dta", clear
keep if inlist(type,"Total","Urban","Rural")

/*  Aggregate total poverty rates across regions */
preserve 
collapse (mean) hc215 (mean) hc685 (rawsum) pop [aw=pop],by(type)
gen region = "WLD"

tempfile wld 
save `wld'
restore

collapse (mean) hc215 (mean) hc685 (rawsum) pop [aw=pop],by(region type)
append using `wld'
br if type=="Total"
encode type, gen(urban_)
recode urban (1 = 0) (2 = 2) (3 = 1), gen(urban)
label define urban_lbl 1 "Urban" 0 "Rural" 2 "Total",  replace 
label values urban urban_lbl
drop type urban_
rename region region_code 
rename hc215 hc_a 
rename hc685 hc_b 
lab var hc_a "Percent of population living below $2.15 a day"
lab var hc_b "Percent of population living below $6.85 a day"
compress
save "$ch1_data_processed/global_poor_location.dta", replace



/*
// Check if the data sets are the same
use "$ch1_data_processed/global_poor_location.dta", clear 
rename hc_a hc_a_
rename hc_b hc_b_ 
merge 1:1 region_code urban using "$ch1_data_processed/global_poor_location_archived.dta"

gen double d_hc215 = round(abs(hc_a-hc_a_),0.0001)
sum d_hc215

gen double d_hc685 = round(abs(hc_b-hc_b_),0.0001)
sum d_hc685
br if region_code=="SSA"

