

/*******************************************************************************
	Estimate poverty rate by education status by region

	Written by: Samuel Kofi Tetteh Baah (stettehbaah@worldbank.org)
	Last date modified: 13 November 2024     
*******************************************************************************/


// Load global distribution
use "$ch1_data_raw/other/global_profile_lineup_2022_country_level.dta", clear
keep if inlist(type,"Primary (complete or incomplete)","Secondary (complete or incomplete)","Tertiary (complete or incomplete)","No education")

/*  Aggregate total poverty rates across regions */
preserve 
collapse (mean) hc215 (mean) hc685 (rawsum) pop [aw=pop],by(type)
gen region = "WLD"

tempfile wld 
save `wld'
restore

collapse (mean) hc215 (mean) hc685 (rawsum) pop [aw=pop],by(region type)
append using `wld'

encode type, gen(edu)
drop type
rename region region_code 
rename hc215 sch_hc215 
rename hc685 sch_hc685 
lab var sch_hc215 "Percent of population living below $2.15 a day"
lab var sch_hc685 "Percent of population living below $6.85 a day"
compress
save "$ch1_data_processed/global_poor_schooling.dta", replace


/*
// Check if the data sets are the same
use "$ch1_data_processed/global_poor_schooling.dta", clear 
rename sch_hc215 sch_hc215_
rename sch_hc685 sch_hc685_ 
merge 1:1 region_code edu using "$ch1_data_processed/global_poor_schooling_archived.dta"

gen double d_hc215 = round(abs(sch_hc215-sch_hc215_),0.0001)
sum d_hc215

gen double d_hc685 = round(abs(sch_hc685-sch_hc685_),0.0001)
sum d_hc685
br if region_code=="SSA"


