
/*******************************************************************************
	Estimate regional poverty rate by age

	Written by: Samuel Kofi Tetteh Baah (stettehbaah@worldbank.org)
	Last date modified: 13 November 2024     
*******************************************************************************/


// Load global distribution
use "$ch1_data_raw/other/global_profile_lineup_2022_country_level.dta", clear
keep if inlist(type,"youth [15-24]","child [0-17]","adult [25+]")
replace type = "child" if type=="child [0-17]"
replace type = "adult" if type=="adult [25+]"
replace type = "youth" if type=="youth [15-24]"

/*  Aggregate poverty rates across regions */
preserve 
collapse (mean) hc215 (mean) hc685 (rawsum) pop [aw=pop],by(type)
gen region = "WLD"

tempfile wld 
save `wld'
restore

collapse (mean) hc215 (mean) hc685 (rawsum) pop [aw=pop],by(region type)
append using `wld'

rename type age_type
rename region region_code 
lab var hc215 "Percent of population living below $2.15 a day"
lab var hc685 "Percent of population living below $6.85 a day"
compress
save "$ch1_data_processed/global_poor_age.dta", replace

/*
// Check if the data sets are the same
use "$ch1_data_processed/global_poor_age.dta", clear
rename hc215 hc215_
rename hc685 hc685_ 
merge 1:1 region_code age_type using "$ch1_data_processed/global_poor_age_archived.dta"

gen double d_hc215 = round(abs(hc215-hc215_),0.0001)
sum d_hc215

gen double d_hc685 = round(abs(hc685-hc685_),0.0001)
sum d_hc685
br if region_code=="SSA"



